==> flutter_payumoney_plugin-0.0.4.tar.gz: example/lib/main.dart <==
import 'package:flutter/material.dart';
import 'dart:async';

import 'package:flutter/services.dart';
import 'package:flutter_payumoney_plugin/flutter_payumoney_plugin.dart';

void main() => runApp(MyApp());

class MyApp extends StatefulWidget {
  @override
  _MyAppState createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {
  String _platformVersion = 'Unknown';

  @override
  void initState() {
    super.initState();
    initPlatformState();
  }

  // Platform messages are asynchronous, so we initialize in an async method.
  Future<void> initPlatformState() async {
    String platformVersion;
    // Platform messages may fail, so we use a try/catch PlatformException.
    try {
      platformVersion = await FlutterPayumoneyPlugin.platformVersion;
    } on PlatformException {
      platformVersion = 'Failed to get platform version.';
    }

    // If the widget was removed from the tree while the asynchronous platform
    // message was in flight, we want to discard the reply rather than calling
    // setState to update our non-existent appearance.
    if (!mounted) return;

    setState(() {
      _platformVersion = platformVersion;
    });
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Scaffold(
        appBar: AppBar(
          title: const Text('Plugin example app'),
        ),
        body: Center(
          child: Column(
            children: <Widget>[
              Text('Running on: $_platformVersion\n'),
//              SizedBox(height: 30),
//              RaisedButton(
//                child: Text("Payment"),
//                color: Colors.blue,
//                onPressed: (){
//                  FlutterPayumoneyPlugin.payUMoneyPayment(
//                    environmentMode: 0,
//                    email: "testuser@grr.la",
//                    amount: "5",
//                    formName: "Test Product",
//                    mobile: "9726230430",
//                    UserName: "Test User"
//                  );
//                },
//              )

            ],
          ),
        ),
      ),
    );
  }
}

==> flutter_payumoney_plugin-0.0.5.tar.gz: example/lib/main.dart <==
import 'package:flutter/material.dart';
import 'dart:async';

import 'package:flutter/services.dart';
import 'package:flutter_payumoney_plugin/flutter_payumoney_plugin.dart';

void main() => runApp(MyApp());

class MyApp extends StatefulWidget {
  @override
  _MyAppState createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {
  String _platformVersion = 'Unknown';
  String paymentID = "";

  @override
  void initState() {
    super.initState();
    initPlatformState();
  }

  // Platform messages are asynchronous, so we initialize in an async method.
  Future<void> initPlatformState() async {
    String platformVersion;
    // Platform messages may fail, so we use a try/catch PlatformException.
    try {
      platformVersion = await FlutterPayumoneyPlugin.platformVersion;

    } on PlatformException {
      platformVersion = 'Failed to get platform version.';
    }

    // If the widget was removed from the tree while the asynchronous platform
    // message was in flight, we want to discard the reply rather than calling
    // setState to update our non-existent appearance.
    if (!mounted) return;

    setState(() {
      _platformVersion = platformVersion;
    });
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Scaffold(
        appBar: AppBar(
          title: const Text('Plugin example app'),
        ),
        body: Center(
          child: Column(
            children: <Widget>[
              Text('Running on: $_platformVersion\n'),
              SizedBox(height: 30),
              RaisedButton(
                child: Text('Payment ID: $paymentID\n'),
                color: Colors.blue,
                onPressed: (){
                  FlutterPayumoneyPlugin.payUMoneyPayment(
                    environmentMode: 0,
                    email: "testuser@grr.la",
                    amount: "5",
                    formName: "Test Product",
                    mobile: "9726230431",
                    UserName: "Test User"
                  ).then((value) {

                    print('PAYMENT ID: $value');


                  });
                },
              )

            ],
          ),
        ),
      ),
    );
  }
}
